@@ -11,25 +11,35 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-// Exporter is a prometheus exporter using multiple Factories to collect and export system metrics.
+// Package collector includes all individual collectors to gather and export system metrics.
 package collector
 
 import (
 	"github.com/prometheus/client_golang/prometheus"
+	"github.com/prometheus/common/log"
 )
 
+// Namespace defines the common namespace to be used by all metrics.
 const Namespace = "node"
 
+// Factories contains the list of all available collectors.
 var Factories = make(map[string]func() (Collector, error))
 
-// Interface a collector has to implement.
-type Collector interface {
-	// Get new metrics and expose them via prometheus registry.
-	Update(ch chan<- prometheus.Metric) (err error)
+func warnDeprecated(collector string) {
+	log.Warnf("The %s collector is deprecated and will be removed in the future!", collector)
 }
 
-// TODO: Instead of periodically call Update, a Collector could be implemented
-// as a real prometheus.Collector that only gathers metrics when
-// scraped. (However, for metric gathering that takes very long, it might
-// actually be better to do them proactively before scraping to minimize scrape
-// time.)
+// Collector is the interface a collector has to implement.
+type Collector interface {
+	// Get new metrics and expose them via prometheus registry.
+	Update(ch chan<- prometheus.Metric) error
+}
+
+type typedDesc struct {
+	desc      *prometheus.Desc
+	valueType prometheus.ValueType
+}
+
+func (d *typedDesc) mustNewConstMetric(value float64, labels ...string) prometheus.Metric {
+	return prometheus.MustNewConstMetric(d.desc, d.valueType, value, labels...)
+}
